'use strict';

Object.defineProperty(exports, "__esModule", {
	value: true
});

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _classnames = require('classnames');

var _classnames2 = _interopRequireDefault(_classnames);

var _Actions = require('../../Actions');

var _ItemTitle = require('../ItemTitle');

var _ItemTitle2 = _interopRequireDefault(_ItemTitle);

var _Display = require('../Display/Display.propTypes');

var _Display2 = _interopRequireDefault(_Display);

var _DisplayTable = require('./DisplayTable.scss');

var _DisplayTable2 = _interopRequireDefault(_DisplayTable);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function cellContent(isTitle, item, column, titleProps, id) {
	if (isTitle) {
		return _react2.default.createElement(_ItemTitle2.default, {
			id: id && id + '-title',
			item: item,
			titleProps: titleProps
		});
	}
	if (item[column.key] instanceof Array) {
		return _react2.default.createElement(_Actions.Actions, {
			actions: item[column.key],
			link: true,
			hideLabel: true
		});
	}
	return item[column.key];
}

function RowRenderer(props) {
	var id = props.id,
	    item = props.item,
	    itemProps = props.itemProps,
	    titleProps = props.titleProps;

	var _ref = itemProps || {},
	    classNameKey = _ref.classNameKey,
	    onToggle = _ref.onToggle,
	    isSelected = _ref.isSelected,
	    selectedClass = _ref.selectedClass;

	var checkboxColumn = onToggle && isSelected ? _react2.default.createElement(
		'td',
		null,
		_react2.default.createElement('input', {
			id: id && id + '-check',
			type: 'checkbox',
			onChange: function onChange(e) {
				onToggle(e, item);
			},
			checked: isSelected(item)
		})
	) : null;
	var classes = (0, _classnames2.default)(classNameKey && item[classNameKey], isSelected && isSelected(item) && (selectedClass || 'active'));
	return _react2.default.createElement(
		'tr',
		{ id: id, className: classes },
		checkboxColumn,
		props.columns.map(function (column, index) {
			var isTitle = column.key === titleProps.key;
			var cell = cellContent(isTitle, item, column, titleProps, id);

			// actions are only on title and on 'text' display mode
			var displayModeKey = titleProps.displayModeKey;

			var displayActions = isTitle && (!displayModeKey || !item[displayModeKey] || item[displayModeKey] === 'text');
			var actions = displayActions ? _react2.default.createElement(_Actions.Actions, {
				actions: item.actions || [],
				hideLabel: true,
				link: true
			}) : null;

			return _react2.default.createElement(
				'td',
				{ key: index },
				cell,
				actions
			);
		})
	);
}
RowRenderer.propTypes = {
	id: _react.PropTypes.string,
	item: _react.PropTypes.object, // eslint-disable-line react/forbid-prop-types
	columns: _react.PropTypes.arrayOf(_react.PropTypes.shape({ key: _react.PropTypes.string.isRequired })).isRequired,
	itemProps: _Display2.default.itemProps,
	titleProps: _ItemTitle2.default.propTypes.titleProps
};

function ListHeader(props) {
	var columns = props.columns,
	    isSelected = props.isSelected,
	    onToggleAll = props.onToggleAll;

	return _react2.default.createElement(
		'tr',
		null,
		isSelected && onToggleAll && _react2.default.createElement('th', null),
		columns.map(function (column, index) {
			return _react2.default.createElement(
				'th',
				{ key: index },
				column.label
			);
		})
	);
}
ListHeader.propTypes = {
	columns: _react.PropTypes.arrayOf(_react.PropTypes.shape({ label: _react.PropTypes.string })),
	isSelected: _react.PropTypes.func,
	onToggleAll: _react.PropTypes.func
};

/**
 * @param {array} columns the array of column definitions
 * @param {array} items the array of items to display
 * @param {object} titleProps the title configuration props
 * @example
 const props = {
	items: [
		{
			id: 1,
			name: 'Title with actions',
			created: '2016-09-22',
			modified: '2016-09-22',
			author: 'Jean-Pierre DUPONT',
			actions: [{
				label: 'edit',
				icon: 'fa fa-edit',
				onClick: action('onEdit'),
			}],
			icon: 'fa fa-file-excel-o',
			display: 'text',
		},
		{
			id: 2,
			name: 'Title in input mode',
			created: '2016-09-22',
			modified: '2016-09-22',
			author: 'Jean-Pierre DUPONT',
			icon: 'fa fa-file-pdf-o',
			display: 'input',
		},
	],
	columns: [
		{ key: 'id', label: 'Id' },
		{ key: 'name', label: 'Name' },
		{ key: 'author', label: 'Author' },
		{ key: 'created', label: 'Created' },
		{ key: 'modified', label: 'Modified' },
	],
	titleProps: {
		key: 'name',
		iconKey: 'icon',
		displayModeKey: 'display',
		onClick: action('onClick'),
		onEditCancel: action('onEditCancel'),
		onEditValidate: action('onEditValidate'),
	},
};
 <DisplayTable {...props} />
 */
function DisplayTable(props) {
	var id = props.id,
	    columns = props.columns,
	    items = props.items,
	    itemProps = props.itemProps,
	    titleProps = props.titleProps;

	var _ref2 = itemProps || {},
	    isSelected = _ref2.isSelected,
	    onToggleAll = _ref2.onToggleAll;

	var className = (0, _classnames2.default)('table', 'tc-list-display-table', _DisplayTable2.default.table);
	return _react2.default.createElement(
		'table',
		{ className: className },
		_react2.default.createElement(
			'thead',
			null,
			_react2.default.createElement(ListHeader, {
				columns: columns,
				onToggleAll: onToggleAll,
				items: items,
				isSelected: isSelected,
				id: id
			})
		),
		_react2.default.createElement(
			'tbody',
			null,
			items.map(function (item, index) {
				return _react2.default.createElement(RowRenderer, {
					id: id && id + '-' + index,
					key: index,
					columns: columns,
					item: item,
					itemProps: itemProps,
					titleProps: titleProps
				});
			})
		)
	);
}

DisplayTable.propTypes = _Display2.default;

DisplayTable.defaultProps = {
	items: [],
	titleProps: { key: 'name' }
};

exports.default = DisplayTable;